@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: compat.h,v 1.24 2004/10/19 20:28:05 mbarbon Exp $
-// Copyright:   (c) 2000-2003 Mattia Barbon
+// RCS-ID:      $Id: compat.h,v 1.26 2006/09/07 20:45:27 mbarbon Exp $
+// Copyright:   (c) 2000-2003, 2006 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -117,7 +117,7 @@
 
 #define WXINTL_NO_GETTEXT_MACRO 1
 
-#if defined(WIN32) || defined(__CYGWIN__)
+#if defined(__WXMSW__)
 #  if WXPERL_P_VERSION_GE( 5, 6, 0 )
 #    define WXXS( name ) __declspec(dllexport) void name( pTHXo_ CV* cv )
 #  else
